%% You can run this file in cell mode: each cell (starting with %%) can be run by pressing CTRL+ENTER inside it

%% Initialization

% sampling interval
Ts = 0.05;
% create model
% the reward function is "normalized LQR" = -x' Qrew x - u' Rrew u, scaled and translated into [0,1]
% maxu is the maximum input voltage, Ts is the sampling period
model = ipsetup_problem('model', 'rewtype=nlqr Qrew=[1,0;0,0.01] Rrew=0.3', 'type=ip maxu=3', sprintf('Ts=%f', Ts));

% set the discount factor
discount = 0.9;

%% Run the uniform planner

% configure the planner
cfg = struct;
cfg.n = 100;           % budget of node expansions at each step
cfg.U = [-3 0 3];      % discretized action space, in volts for the inv pend
cfg.discount = discount;

% example of running the uniform planner in closed loop
x0 = [-pi; 0];          % initial state = pointing down
K = 60;                 % length of trajectory
% initialize signal history
X = NaN(2, K+1); U = NaN(1, K+1); R = NaN(1, K+1);
X(:, 1) = x0;
% visualize the initial state (comment these lines out if you don't want the picture)
viscfg = struct;
viscfg.model = model; viscfg.trial = 1; viscfg.mpcstep = 1;
viscfg.X = X; viscfg.k = 0; viscfg.ktotal = 0;
[figh, viscfg.gview] = dc_ip_visualize(viscfg);    % note view is stored, else it's recreated each time
for k = 1:K,
    % run the planner at the current state
    % see upd code for the statistics you can examine in planinfo
    [U(:, k), planinfo] = upd(X(:, k), model, cfg);
    % execute the action on the system, saving state and reward on the history
    [X(:, k+1), R(k+1)] = feval(model.fun, model, X(:, k), U(:, k));
    % visualize updated state (comment these lines out if you don't want the picture)
    viscfg.X = X; viscfg.k = k; viscfg.ktotal = k;
    [figh, viscfg.gview] = dc_ip_visualize(viscfg);
end;

%% Plot the resulting trajectory
% some transformations to a standard format are needed
h = struct;
h.t = 0 : Ts : K*Ts; h.x = X; h.u = U; h.r = R; h.Ns = K;
plotcfg = struct;
plotcfg.model = model;
plotcfg.traj = h;
dc_plot(plotcfg);



